# frozen_string_literal: true

require 'active_model'

# Module
module Yade
  module Project
    module Rest
      module Model
        class ProjectModule
          include ActiveModel::Model
          include ActiveModel::Validations
          include ActiveModel::Serializers::JSON

          attr_accessor :id, :name, :enabled, :languageType, :buildToolType, :vcsId, :projectId
          attr_reader :home

          validates_presence_of 'id', 'name', 'home', 'languageType', 'buildToolType', 'vcsId', 'projectId'

          def attributes
            instance_values
          end

          def home
            project_client = Yade::Project::Rest::Client::ProjectClient.new
            project = project_client.get(projectId)

            "#{project.home}/src/#{name}"
          end

          def installed?
            File.directory?(home)
          end
        end
      end
    end
  end
end
